bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 31. Aventiure
___________________________________________________ #### <Wie si ze chirchen giengen>
| ### ir kvolent so die ringe so sprach Volker ### ia wene div naht welle vns niht wern mer ### ich chiusez von dem lvfte ez ist vil schiere tach ### do wacten si der manigen der noch slafende lach
###### 1788 | ### Do schein der liehte mane den gesten in den sal ### Hagne begvnde weken die rittere vber al ### ob si zvo dem mvnster ze messe wolden gan ### nach siten christenlichen man vil lveten began
###### 1789 | ### Si svngen vngeliche daz da vil wol schein ### kristen vn– heide warn niht enein ### do wolden zvo der chirchen Gvntheres man ### si warn von den betten algeliche gestan
###### 1790 | ### Do næten sich die reken in also gvot gewant ### daz nie helde mere in deheines kvniges lant ### ie bezzer kleider brahten daz waz Hagnen læit ### er sprach ia svlt ir helde hie tragen ander klæit
###### 1791 | ### Ia sint iv doch genvogen div mere wol bekant [73a] ### nv traget fvr die rosen div wafen an der hant ### fvr schappel wol gesteim die liehten helme gvot ### sit wir wol erchennen der argen Kriemhilde mvot
###### 1792 | ### Wir mvezzen heint striten daz wil ich iv sagen ### ir svlt fvr sidin hemde <hasperge> tragen ### vn– fvr die richen mentel gvote schilde wit ### ob iemen mit iv zvrne daz ir vil werlichen sit
###### 1793 | ### Mine vil lieben dar zvo mage vnd man ### ir svlt vil willeclichen zvo der chirken gan ### vn– klaget gote dem richen sorge vn– iwer not ### vn– wizzet sicherlichen daz vns nahet der tot
###### 1794 | ### Ir svlt ovch niht vergezzen swaz ir habet getan ### vn– svlt vil vlizeclichen da gein got stan ### dez wil ich ivch warnen reken vil her ### ez enwelle got von himel ir vernemet messe nimmer mer
###### 1795 | ### Svs giengen zvo dem mvnster die fvrsten vn– ir man ### vf dem vronen vrithove da hiez si stille stan ### Hagne der kvene daz si sich schieden niht ### er sprach ia weiz noch niemen waz vns von den Hvnen geschiht
###### 1796 | ### Leget mine vrivnde die schilde fvr den fvoz ### vnd geltet ob iv inemen biete swachen grvoz ### mit tiefen verchwunden daz ist der Hagnen rat ### daz ir so werdet fvnden sam ez iv lobelichen stat
###### 1797 | ### Uolker vn– Hagne die zwene giengen dan ### fvr daz wite mvnster daz wart dvrch daz getan ### daz si daz wolden wizzen daz dez kvniges wip ### mvose mit in dringen ia waz vil grimmich ir lip
###### 1798 | ### Do kom der wirt des landes vn– ovch sin schoene wip ### mit richem gewande geziert waz ir lip ### der vil snellen reken die man <sach> mit im varn ### do kos man hohe stovben von den Kriemhilde scharn
###### 1799 | ### Do der kvnich riche svs gewafent sach ### die kvnige vn– ir gesinde wie balde er do sprach ### wie sihe ich vrivnde mine vnder helmen gan ### mir ist læit vf min triwe vn– hat in iemen getan
###### 1800 | ### Ich solz in gerne bvezen swie si dvnchet gvot ### hat iemen si beswert daz herce vn– ovch den mvot ### des bringe ich si wol innen daz ez mir ist vil læit ### swaz si mir gebietent dez bin ich allez in bereit
###### 1801 | ### Dez <antwvrte> Hagne vns hat niemen niht getan ### ez ist site miner herren daz si gewafent gan ### ze allen hohgeziten ze vollen drin tagen ### swaz man vns hie tete wir soldens Ecelen sagen
###### 1802 | ### Vil wol gehorte Kriemhilt waz Hagne gesprach ### wie rehte vientliche si im vnder div ovgen sach ### si wolde doch niht melden den site von ir lant ### swie lange si den hete ze den Bvrgonden erchant
###### 1803 | ### Swie grimme vn– swie starche si in vient wære ### hete iemen geseit Eceln div rehten mere [73b] ### er hete wol vnderstanden daz doch sit da geschach ### dvrch ir vil starchen vbermvot ir deheiner ims veriach
###### 1804 | ### Do gie vil groziv menige mit der kvniginne dan ### do enwolden dise zwene idoch niht hoher stan ### zwæier hande breite daz waz den Hvnen leit ### ia mvose si sich dringen mit den helden vil gemeit
###### 1805 | ### Eceln kamerere die dvhte daz niht gvot ### ia heten si den reken erzvrnet do den mvot ### wan daz si entorsten vor dem kvnige her ### da waz vil michel dringen vn– do niht anders mer
###### 1806 | ### Do man do gote gediende vn– daz si wolden dan ### vil balde kom ze rossen manich Hvnen man ### do waz bi Kriemhilde vil manich schoene meit ### wol siben tvsent degne bi der kvniginne reit
###### 1807 | ### Kremhilt mit ir vrowen in div venster gesaz ### zvo Eceln dem richen liep waz im daz ### si wolden schovwen riten helde vil gemeit ### hey waz vremder reken vor in vf dem hove reit
###### 1808 | ### Do waz ovch der marschalch mit den knehten chomen ### Dancwart der vil kvene hete zvo im genomen ### sins herren ingesinde von Bvrgonden lant ### div ros man wol gesatelt den kvenen Niblvngen vant
###### 1809 | ### Do ze rossen komen die kvnige vn– ovch ir man ### Volker der starch raten daz began ### si solden buhvrtyern nah ir landes siten ### des wart von den helden sit vil herlich geriten
###### 1810 | ### Der helt het in geraten des si doh niht verdroz ### der bvhvrt vn– daz schallen wurden beidiv groz ### vf den hof vil witen kom vil manich man ### Ecel vn– Kriemhilt daz selbe schowen began
###### 1811 | ### Vf den bvhvrt komen sehs hvndert degne ### Dietriches reken den gesten zegegne ### si wolden kvrzwile mit den Bvrgonden han ### het er ins gegvnnen si hetenz gerne getan
###### 1812 | ### Zey waz gvoter reken in da nach ræit ### dem herren Dietriche wart daz geseit ### mit Gvnthers mannen daz spil er in verbot ### er vorhte siner manne dez gie im sicherlichen not
###### 1813 | ### Do dise von Berne gescheiden warn dan ### do komen von Bechlarn Rvedegers man ### fvnf hvndert vnder schilden fvr den sal geriten ### liep were dem marcraven daz siz heten vermiten
###### 1814 | ### Do riet er wislichen zvo in an die schar ### vn– seite sinen mannen si wern dez gewar ### daz in vnmvote warn Gvnthers man ### do si den bvhvrt liezen ez wer im liebe getan
###### 1815 | ### Do von in geschieden die helde vil gemeit ### do komen die von Dvringen als vns daz ist geseit ### vn– der von Tenemarchen wol tvsent kvener man [74a] ### von stichen sach man vliegen vil trvnzune dan
###### 1816 | ### Irnvrit vn– Hawart in den buhurt ritten ### ir heten die von Rine vil stoltzlich erpiten ### si buhten manige tyost den von Dvringen lant ### dez wart von stichen dvrchel manic herlicher rant
###### 1817 | ### Do kom der herre Bloedel mit drin tvsent dar ### Ecel vn– Kriemhilt namen sin wol war ### wan vor in beiden div ritterschaft geschach ### div kvnigin ez gerne dvrh leit der Bvrgonde sach
###### 1818 | ### Schrvtan vn– Gybeche vf den bvhurt riten ### Ramvnch vn– Hornboge nach hvnischen siten ### si hielten gein den heiden von Bvrgonden lant ### die schefte dræten hohe vber des kvniges sales want
###### 1819 | ### Do waz ir kvrtzwile so michel vnde groz ### daz dvrch die covertvre der blanke sweiz do vloz ### von den gvoten rossen div die helde riten ### si versvohtenz an die Hvnen mit vil hochverten siten
###### 1820 | ### Do sprach der kvene Volker ein edel spilman ### ich wen vns dise reken turren niht bestan ### ich horte ie sagen mere si wern vns gehaz ### nv enkvnd ez sich gefvegen zware ninder in baz
###### 1821 | ### Ce herbergen fvern sprach aber Volker ### sol man vns die moere vn– riten danne mer ### hin gein abende so ez virdet zit ### waz ob div kvnigin den lop den Bvrgonden git
###### 1822 | ### Do sahens einen ritter so wæigerlichen gie ### daz ez al der Hvenen getet neheiner nie ### ia moht er in den ziten wol haben herzen trvt ### er fvor so wol gekleidet sam ez were ein edel brvt
###### 1823 | ### Do sprach aber Volker wie moht ich daz verlon ### iener trvt der vrowen mvoz ein gepovze han ### ez chan niemen gescheiden ez gat im an den lip ### ia enrvch ich ob ez zvrnet dez kvnic Eceln wip
###### 1824 | ### Nein dvrch min liebe sprach der kvnich san ### ez wizent vns die lvte ob wir si bestan ### lat ez heben die <Hvnen> daz fveget sich noh baz ### dannoch der kvnich Ecel bi der kvniginne saz
###### 1825 | ### Ich wil den bvhvrt mern sprach do Hagne ### lat die vrowen schowen vn– die degne ### wie wir kvnnen ritten daz ist gvot getan ### man git doch lop deheinen des kvnic Gvntheres man
###### 1826 | ### Volker der vil snelle den bvhurt wider reit ### daz wart sit maniger vrowen grozlichen leit ### er stach dem richen Hvnen daz sper dvrh den lip ### daz sach man sit beweinen beide meit vn– wip
###### 1827 | ### Uil harte hvrteclichen Hagne vn– sine man ### mit sehzek siner degne riten er began ### nach dem videlere da daz spil geschach ### Ecel vn– Kriemhilt ez bescheidenlichen sach [74b]
###### 1828 | ### Do wolden die dri kvnige den kvenen spilman ### bi den vinden niht an hvote lan ### da wart von tvsent helden vil kvntlich geriten ### si taten daz si wolden in vil hochverten siten
###### 1829 | ### Do der riche Hvne ze tode waz erslagen ### man horte sine mage rvofen vnde klagen ### do vragte al daz gesinde wer hat ez getan ### daz hat der videlere Volker der kvene spilman
###### 1830 | ### Nach swerten vnd schilden riefen da zehant ### des marcraven mage von der Hvnen lant ### si wolden Volkern ze tode erslagen han ### der wirt vz eime venster vil harte gahen began
###### 1831 | ### Do hvop sich von den Hvnen allenthalben schal ### die kvnige vn– ir gesinde erbeizten fvr den sal ### div ros ze rvch ze stiezen die Bvrgonden man ### do kom kvnich Ecel der herre ez scheiden began
###### 1832 | ### Ein dez Hvnen mage den er bi im vant ### ein vil scharfez wafen brach erm vz der hant ### do slvog ers alle widere wan im waz vil zorn ### wie hete ich minen dienst an disen helden verlorn
###### 1833 | ### ob ir bi mir hie slveget disen spilman ### sprach der kvnich Ecel daz were missetan ### ich sach vil wol sin riten do er den Hvenen stach ### daz ez an sin schvlde von eime struche geschach
###### 1834 | ### Ir mvezet mine geste vride lazzen han ### do wart er ir geleite div ros zoch man dan ### zvo den herbergen si heten manigen kneht ### die in mit vlize warn ze allen dienste gereht
###### 1835 | ### Der wirt mit sinen vrvnden in den palas gie ### zorn er mer deheinen da niht werden lie ### do rihte man die tische daz wazzer man in trvoch ### da heten die von Rene der starchen vinde genvoch
###### 1836 | ### E die herren gesezen des waz harte lanch ### div Kriemhilde sorge si ze sere twanch ### si sprach fvrste von Berne ich svoche dinen rat ### helfe vnd genade min dinch mir angestliche stat
###### 1837 | ### Des antwurte ir Hiltebrant ein reke lobelich ### swer sleht die Niblunge der tvot ez ane mich ### dvrh deheins schatzes liebe ez mag im werden læit ### si sint noh wnbetwungen die snellen ritter gemeit
###### 1838 | ### Do sprach in sinen zvhten dar zvo her Dietrich ### die rede lat beliben kvniginne rich ### mir habent iwer mage der læide niht getan ### daz ich die degne kvene mit strite welle bestan
###### 1839 | ### Div bete ivch lvzel ert vil edel fvrsten wip ### daz ir iwern magen ratet an den lip ### si komen vf genade her in dize lant ### Sifrit ist vnerrochen von Dietriches hant
###### 1840 | ### Do si der vntriwe an dem Bernere niene vant [75a] ### do lobete si also balde in Bloedelines hant ### eine wite marche die Nvodvnch e besaz ### sit do slvog in Dancwart daz er der gabe gar vergaz
###### 1841 | ### Si sprach dv solt mir helfen herre Blvodelin ### ia sint in disem hvse die viende min ### die Sifriden slvogen den minen liebe man ### swer mir daz hilfet rechen den bin ich immer vndertan
###### 1842 | ### Dez antwurte ir Bloedel vrowe nv wizzet daz ### ia entar ich in vor Ecele geraten cheinen haz ### wan er iwer mage vro vil gerne siht ### tete <ich> in iht ze leide der kvnich vertrvege mir sin niht
###### 1843 | ### Neina herre Bloedel ich bin dir immer holt ### ia gib ich dir ze miete silber vnd golt ### vn– ein maget schoene daz Nvodvnges wip ### so maht dv gerne trveten ir vil minneclichen lip
###### 1844 | ### Daz lant zvo den bvrgen wil ich dir allez geben ### so mahtv ritter edel mit vrovden immer leben ### gewinnestv die marche da Nvodvnch inne saz ### swaz ich dir lobe hivte mit triwen leiste ich dir daz
###### 1845 | ### Do der herre Bloedel die miete vernam ### vn– daz im dvrch ir schoene div vrowe wol gezam ### mit strite wand er dienen daz minnecliche wip ### darvmbe mvose der reke do verliesen den lip
###### 1846 | ### Er sprach zer kvniginne get wider in den sal ### e ez iemen werde innen so hebe ich einen schal ### ez mz erarnen Hagne daz er iv hat getan ### ich antwurt iv gebvnden dez kvnic Gvntheres man
###### 1847 | ### Nv wafent ivch sprach Bloedel alle die ich han ### wir svln den vienden in die herberge gan ### dez wil mich niht erlazen daz Eceln wip ### darvmbe svln wir helde alle wagen den lip
###### 1848 | ### Do div kvniginne Bloedelinen lie ### in des strites willen ze tische si do gie ### mit Eceln dem kvnige vn– ovch mit sinen man ### si heze swinde ræte an die geste getan
###### 1849 | ### Do der strit niht anders kvnde sin erhaben ### Kriemhilt leit daz alte in ir herzen waz begraben ### do hiez si tragen ze tische den Eceln svn ### wie kvnd ein wip dvrch rache immer vreislicher tvon
###### 1850 | ### Dar giengen an der stvnde vier Eceln man ### si trvogen Ortlieben den ivngen kvnich dan ### zvo der fvrsten tische da ovch Hagne saz ### dez mvose daz kint ersterben dvrch sinen mortlichen haz
###### 1851 | ### Do der kvnich riche sinen svn ersach ### zvo sinen konemagen er gvetlichen sprach ### nv sehet vrivnde mine daz ist min einich svn ### vn– ovch iwere swester daz mag iv allen wesen frvm
###### 1852 | ### <Gevaht> er nach dem kvnne er wirt ein kvene man ### rich vn– vil edel starch vn– wolgetan [75b] ### lebe ich dehein wile ich gib im zwelf lant ### so mag iv wol gedienen des ivngen Ortliebes hant
###### 1853 | ### Darvmbe bite ich gerne ivch lieben vrivnt min ### swenn ir ze lande ritet wider an den Rin ### so svlt ir mit iv fvern iwer swester svn ### vn– svlt ovch an dem kinde vil genediclichen tvon
###### 1854 | ### Vnd ziehet in ze ern vntz er werde man ### hat iv in den landen iemen icht getan ### daz hilfet er iv rechen gewahset im sin lip ### die rede horte ovch Kriemhilt des kvnich Eceln wip
###### 1855 | ### Im solden wol getrowen dise degne ### gewuechse er ze manne so sprach Hagne ### doch ist der kvnich ivnge so veiclich getan ### man sol mich sehen selten ze hove nah Ortliebe gan
###### 1856 | ### Der kvnich an Hagnen blicte div rede was im leit ### swie niht darvmbe reite der fvrste gemeit ### ez trvobte im daz herze vn– swarte den mvot ### do waz Hagnen wille niht ze kvrtzwile gvot
###### 1857 | ### Ez tet den fvrsten allen mit dem kvnige we ### daz Hagne von dem kinde hete gesprochen e ### daz siz vertragen solden daz waz in vngemach ### si wessen niht der mere waz von dem reken sit geschach

<<< Übersicht <<< vorige Seite nächste Seite >>>